@@ -267,6 +267,14 @@ GList            *thunar_file_list_to_thunar_g_file_list (GList
 
 gboolean          thunar_file_is_desktop                 (const ThunarFile *file);
 
+const gchar*      thunar_file_get_metadata_setting       (ThunarFile             *file,
+                                                          const gchar            *setting_name);
+void              thunar_file_set_metadata_setting       (ThunarFile             *file,
+                                                          const gchar            *setting_name,
+                                                          const gchar            *setting_value);
+void              thunar_file_clear_directory_specific_settings (ThunarFile      *file);
+gboolean          thunar_file_has_directory_specific_settings   (ThunarFile      *file);
+
 /**
  * thunar_file_is_root:
  * @file : a #ThunarFile.
