@@ -215,7 +215,7 @@ again:
                                                    display_name);
 
               /* check if we should overwrite */
-              if (response == THUNAR_JOB_RESPONSE_YES)
+              if (response == THUNAR_JOB_RESPONSE_REPLACE)
                 {
                   /* try to remove the file. fail if not possible */
                   if (_tij_delete_file (lp->data, exo_job_get_cancellable (EXO_JOB (job)), &err))
@@ -370,7 +370,7 @@ again:
                                                    display_name);
 
               /* check if we should overwrite it */
-              if (response == THUNAR_JOB_RESPONSE_YES)
+              if (response == THUNAR_JOB_RESPONSE_REPLACE)
                 {
                   /* try to remove the file, fail if not possible */
                   if (_tij_delete_file (lp->data, exo_job_get_cancellable (EXO_JOB (job)), &err))
@@ -582,6 +582,7 @@ thunar_io_jobs_move_files (GList *source_file_list,
 
   job = thunar_transfer_job_new (source_file_list, target_file_list,
                                  THUNAR_TRANSFER_JOB_MOVE);
+  thunar_job_set_pausable (job, TRUE);
 
   return THUNAR_JOB (exo_job_launch (EXO_JOB (job)));
 }
@@ -600,6 +601,7 @@ thunar_io_jobs_copy_files (GList *source_file_list,
 
   job = thunar_transfer_job_new (source_file_list, target_file_list,
                                  THUNAR_TRANSFER_JOB_COPY);
+  thunar_job_set_pausable (job, TRUE);
 
   return THUNAR_JOB (exo_job_launch (EXO_JOB (job)));
 }
@@ -707,7 +709,7 @@ _thunar_io_jobs_link_file (ThunarJob *job,
             break;
 
           /* try to delete the file */
-          if (response == THUNAR_JOB_RESPONSE_YES)
+          if (response == THUNAR_JOB_RESPONSE_REPLACE)
             {
               /* try to remove the target file. if not possible, err will be set and
                * the while loop will be aborted */
@@ -716,7 +718,7 @@ _thunar_io_jobs_link_file (ThunarJob *job,
 
           /* tell the caller that we skipped this file if the user doesn't want to
            * overwrite it */
-          if (response == THUNAR_JOB_RESPONSE_NO)
+          if (response == THUNAR_JOB_RESPONSE_SKIP)
             return g_object_ref (source_file);
         }
     }
