@@ -72,6 +72,7 @@ enum
   PROP_LAST_WINDOW_HEIGHT,
   PROP_LAST_WINDOW_WIDTH,
   PROP_LAST_WINDOW_FULLSCREEN,
+  PROP_MISC_DIRECTORY_SPECIFIC_SETTINGS,
   PROP_MISC_ALWAYS_SHOW_TABS,
   PROP_MISC_VOLUME_MANAGEMENT,
   PROP_MISC_CASE_SENSITIVE,
@@ -347,6 +348,18 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                             FALSE,
                             EXO_PARAM_READWRITE);
 
+  /**
+   * ThunarPreferences:misc-directory-specific-settings:
+   *
+   * Whether to use directory specific settings.
+   **/
+  preferences_props[PROP_MISC_DIRECTORY_SPECIFIC_SETTINGS] =
+      g_param_spec_boolean ("misc-directory-specific-settings",
+                            "MiscDirectorySpecificSettings",
+                            NULL,
+                            FALSE,
+                            EXO_PARAM_READWRITE);
+
   /**
    * ThunarPreferences:last-side-pane:
    *
