@@ -1212,6 +1212,13 @@ thunar_shortcuts_model_add_shortcut_with_path (ThunarShortcutsModel *model,
   _thunar_return_if_fail (THUNAR_IS_SHORTCUTS_MODEL (model));
   _thunar_return_if_fail (shortcut->file == NULL || THUNAR_IS_FILE (shortcut->file));
 
+  if (G_LIKELY (shortcut->file != NULL))
+    {
+      /* watch the trash for changes */
+      if (thunar_g_file_is_trash (thunar_file_get_file (shortcut->file)))
+        thunar_file_watch (shortcut->file);
+    }
+
   if (path == NULL)
     {
       /* insert the new shortcut to the shortcuts list */
@@ -1315,30 +1322,22 @@ thunar_shortcuts_model_load_line (GFile       *file_path,
 
   shortcut = g_slice_new0 (ThunarShortcut);
   shortcut->group = THUNAR_SHORTCUT_GROUP_PLACES_BOOKMARKS;
+  shortcut->location = g_object_ref (file_path);
 
   /* handle local and remote files differently */
+  /* If we dont have a thunar-file, we need to set the gicon manually */
   if (thunar_shortcuts_model_local_file (file_path))
     {
       /* try to open the file corresponding to the uri */
       file = thunar_file_get (file_path, NULL);
       if (G_UNLIKELY (file == NULL))
-        {
           shortcut->gicon = g_themed_icon_new ("folder");
-          shortcut->location = g_object_ref (file_path);
-        }
       else
-        {
-          /* make sure the file refers to a directory */
-          if (G_UNLIKELY (thunar_file_is_directory (file)))
-            shortcut->file = file;
-          else
-            g_object_unref (file);
-        }
+          shortcut->file = file;
     }
   else
     {
       shortcut->gicon = g_themed_icon_new ("folder-remote");
-      shortcut->location = g_object_ref (file_path);
     }
 
   shortcut->sort_id = row_num;
@@ -1651,6 +1650,10 @@ thunar_shortcut_free (ThunarShortcut       *shortcut,
 {
   if (G_LIKELY (shortcut->file != NULL))
     {
+      /* drop the file watch on trash */
+      if (thunar_g_file_is_trash (thunar_file_get_file (shortcut->file)))
+        thunar_file_unwatch (shortcut->file);
+
       g_object_unref (shortcut->file);
     }
 
