@@ -32,13 +32,8 @@
 #include <thunar/thunar-thumbnail-cache.h>
 #include <thunar/thunar-file.h>
 
-#if GLIB_CHECK_VERSION (2, 32, 0)
 #define _thumbnail_cache_lock(cache)   g_mutex_lock (&((cache)->lock))
 #define _thumbnail_cache_unlock(cache) g_mutex_unlock (&((cache)->lock))
-#else
-#define _thumbnail_cache_lock(cache)   g_mutex_lock ((cache)->lock)
-#define _thumbnail_cache_unlock(cache) g_mutex_unlock ((cache)->lock)
-#endif
 
 
 
@@ -79,11 +74,7 @@ struct _ThunarThumbnailCache
   GList      *cleanup_queue;
   guint       cleanup_queue_idle_id;
 
-#if GLIB_CHECK_VERSION (2, 32, 0)
   GMutex      lock;
-#else
-  GMutex     *lock;
-#endif
 };
 
 
@@ -144,11 +135,7 @@ thunar_thumbnail_cache_finalize (GObject *object)
   _thumbnail_cache_unlock (cache);
 
   /* release the mutex itself */
-#if GLIB_CHECK_VERSION (2, 32, 0)
   g_mutex_clear (&cache->lock);
-#else
-  g_mutex_free (cache->lock);
-#endif
 
   (*G_OBJECT_CLASS (thunar_thumbnail_cache_parent_class)->finalize) (object);
 }
@@ -758,11 +745,7 @@ static void
 thunar_thumbnail_cache_init (ThunarThumbnailCache *cache)
 {
   /* create a new mutex for accessing the cache from different threads */
-#if GLIB_CHECK_VERSION (2, 32, 0)
   g_mutex_init (&cache->lock);
-#else
-  cache->lock = g_mutex_new ();
-#endif
 
   /* add an additional reference to keep us alive while tre proxy initializes */
   g_object_ref (cache);
